<?php
if (!defined('DC_CONTEXT_ADMIN')) { return; }

$core->addBehavior('adminPostFormSidebar',array('shortURLBehaviors','shortURLDisplay'));
$core->addBehavior('adminAfterCommentDesc',array('shortURLBehaviors','shortCommentURLDisplay'));
if ($core->plugins->moduleExists('pages')) {
	$core->addBehavior('adminPageFormSidebar',array('shortURLBehaviors','shortURLDisplay'));
}
if ($core->plugins->moduleExists('gallery')) {
	$core->addBehavior('adminGalleryFormSidebar',array('shortURLBehaviors','shortURLDisplay'));
	$core->addBehavior('adminGalleryItemFormSidebar',array('shortURLBehaviors','shortURLDisplay'));
}

$core->addBehavior('adminBlogPreferencesForm',array('shortURLBehaviors', 'adminBlogPreferencesForm'));
$core->addBehavior('adminBeforeBlogSettingsUpdate',array('shortURLBehaviors', 'adminBeforeBlogSettingsUpdate'));

# BEHAVIORS
class shortURLBehaviors
{
	public static function shortURLDisplay(record $post = NULL)
	{
		if ($post && $GLOBALS['core']->blog->settings->shortURL->shortURLEnabled) {
			$id = dcShortURL::idConversion($post->post_id);
			$url = $GLOBALS['core']->blog->url.$GLOBALS['core']->url->getBase('shortURL').'/'.$id;
			echo '<div id="shurl-box" class="sb-box"><h4>'.__('Short URL').'</h4><p><a href="'.$url.'">'.$url.'</a></p></div>';
		}
	}

	public static function shortCommentURLDisplay(record $comment = NULL)
	{
		if ($comment && $GLOBALS['core']->blog->settings->shortURL->shortURLEnabled) {
			$id = dcShortURL::idConversion($comment->comment_id);
			$url = $GLOBALS['core']->blog->url.$GLOBALS['core']->url->getBase('shortURLComment').'/'.$id;
			return '<p>'.__('Short URL:').' <a href="'.$url.'">'.$url.'</a></p>';
		}
	}

	public static function adminBlogPreferencesForm(dcCore $core)
	{
		$activate = $core->blog->settings->shortURL->shortURLEnabled ? true : false;
		$prefix = $core->blog->settings->shortURL->shortURLPrefix;
		$commentPrefix = $core->blog->settings->shortURL->shortURLCommentPrefix;
		$backCompatibility = $core->blog->settings->shortURL->shortURLBackCompatibility ? true : false;
		$evenShorter = $core->blog->settings->shortURL->shortURLEvenShorter ? true : false;

		echo "<div class=\"fieldset\"><h4>".__('Short URLs')."</h4>\n";
		echo "<p><label class=\"classic\">".form::checkbox('enableShortURL','1',$activate)."\n".
			__('Enable short URL system.')."</label></p>\n";
		echo "<p><label class=\"classic\">".__('Prefix to use in short URLs:')."\n".
			form::field('shortURLPrefix',10,20,$prefix)."</label></p>\n";
		echo "<p><label class=\"classic\">".__('Prefix to use in short URLs for comments:')."\n".
			form::field('shortURLCommentPrefix',10,20,$commentPrefix)."</label></p>\n";
		echo "<p><label class=\"classic\">".form::checkbox('evenShorterURL','1',$evenShorter)."\n".
			__('Use even shorter URLs than the post/comment id.')."</label></p>\n";
		echo "<p><label class=\"classic\">".form::checkbox('backCompatibleShortURL','1',$backCompatibility)."\n".
			__('Provide backwards compatibility (ie, support postid type URL).')."</label></p>\n";
		echo "</div>\n";
	}
	
	public static function adminBeforeBlogSettingsUpdate(dcSettings $blog_settings)
	{
		$enabled = empty($_POST['enableShortURL']) ? false : true;
		$backCompatibility = empty($_POST['backCompatibleShortURL']) ? false : true;
		$evenShorter = empty($_POST['evenShorterURL']) ? false : true;
		$prefix = empty($_POST['shortURLPrefix']) ? 'shurl' : $_POST['shortURLPrefix'];
		$commentPrefix = empty($_POST['shortURLCommentPrefix']) ? 'shurlc' : $_POST['shortURLCommentPrefix'];
		
		$blog_settings->addNamespace('shortURL');
		$blog_settings->shortURL->put(
			'shortURLEnabled',
			$enabled,
			'boolean',
			'Enable short URL system');
		$blog_settings->shortURL->put(
			'shortURLPrefix',
			$prefix,
			'string',
			'Short URL system prefix');
		$blog_settings->shortURL->put(
			'shortURLCommentPrefix',
			$commentPrefix,
			'string',
			'Short URL system prefix for comments');
		$blog_settings->shortURL->put(
			'shortURLBackCompatibility',
			$backCompatibility,
			'boolean',
			'Still support the old URL system (ie the \'postid\' prefix)');
		$blog_settings->shortURL->put(
			'shortURLEvenShorter',
			$evenShorter,
			'boolean',
			'Use even shorter URLs');
	}
	
}
